import {ST_WITHIN_FILTER_REVERSED} from "./CommonConfig";

const EQUALS = encodeURIComponent("=");
const SEMICOLON = encodeURIComponent(";");

const FROST_SERVER_URL = "http://193.196.138.56/frost-luftdata-api/v1.1";
const FEATURES_OF_INTEREST_URL = `${FROST_SERVER_URL}/FeaturesOfInterest`;
const GEO_JSON_DATA_URL = `${FEATURES_OF_INTEREST_URL}?$top=100&$resultFormat=GeoJSON`;

const OBSERVATIONS_BASE_QUERY = `$orderBy${EQUALS}phenomenonTime+DESC${SEMICOLON}` +
    `$filter=Datastream/ObservedProperty/name eq 'P2'`;

export function getPMGeoJsonUrlWithLastObservation(
    fromDate?: Date,
    toDate?: Date,
    fromValue?: number,
    toValue?: number,
    limitObservations?: number,
) {
    const conditions: string[] = [];

    if (fromValue) {
        conditions.push(`result ge ${fromValue}`);
    }
    if (toValue) {
        conditions.push(`result le ${toValue}`);
    }
    if (fromDate) {
        conditions.push(`phenomenonTime ge ${fromDate.toISOString()}`);
    }
    if (toDate) {
        conditions.push(`phenomenonTime le ${toDate.toISOString()}`);
    }

    const geographicFilters: string[] = [ST_WITHIN_FILTER_REVERSED];

    let filterQuery = "", observationsFilterQuery = "";
    if (conditions.length || geographicFilters.length) {
        filterQuery = "&$filter=" + conditions
            .map(condition => `Observations/${condition}`)
            .concat(geographicFilters)
            .join(" and ");
    }

    if (conditions.length) {
        observationsFilterQuery = `${SEMICOLON}$filter${EQUALS}${conditions.join(" and ")}`;
    }

    const limitObservationsQuery = `${SEMICOLON}$top${EQUALS}${limitObservations || 1}`;

    return `${GEO_JSON_DATA_URL}${filterQuery}` +
        `&$expand=Observations(${OBSERVATIONS_BASE_QUERY}${limitObservationsQuery}${observationsFilterQuery})`;
}


export function getPMHistoryUrl(
    id: number,
    fromDate: Date,
    toDate: Date,
    limitObservations?: number,
) {
    const conditions: string[] = [];
    conditions.push(`phenomenonTime ge ${fromDate.toISOString()}`);
    conditions.push(`phenomenonTime le ${toDate.toISOString()}`);

    let filter = "";
    if (conditions.length) {
        filter = "$filter=" + conditions
            .map(condition => `${condition}`)
            .join(" and ");
    }

    const orderBy = "$orderBy=phenomenonTime";

    const limit = `$top=${limitObservations || 100}`;
    const select = "$select=phenomenonTime,result";
    const queryParams = [select, filter, orderBy, limit].join("&");
    return `${FEATURES_OF_INTEREST_URL}(${id})/Observations?${queryParams}`;
}
