import React from "react";
import {TrafficCacheInfo} from "../../common/TrafficCacheManager";
import {AQIRange, Dictionary} from "../../common/Helpers";
import {DateFilter, HeatingInfo, TrafficVisibilityMode} from "../Map";
import {Button, Dialog, DialogActions, DialogContent, DialogTitle} from "@material-ui/core";
import "./Popup.css";
import {TrafficPopupContent} from "./TrafficPopupContent";
import {PMPopupContent} from "./PMPopupContent";
import {BuildingPopupContent} from "./BuildingPopupContent";

type Id = { id: string };

export type PopupDataInfo = {
    trafficVisibilityMode?: TrafficVisibilityMode,
    type: "traffic" | "pm" | "building";
    trafficInfo?: TrafficCacheInfo & Id;
    buildingInfo?: Id & { heatingInfo?: HeatingInfo; properties: Dictionary<any> };
    pmInfo?: Id & { pm: number; aqiValue: number; aqiRange: AQIRange; description: string; longitude: number, latitude: number };
    dateFilter: DateFilter;
    isFiltered: boolean;
}

type PopupState = {}

type PopupProps = {
    info: PopupDataInfo;
    handleClose: () => void;
}

export class Popup extends React.Component<PopupProps, PopupState> {

    getTitle(): string {
        switch (this.props.info.type) {
            case "traffic":
                return `Traffic Info ${this.props.info.trafficInfo?.id}`;
            case "pm":
                return `PM2.5 Info ${this.props.info.pmInfo?.id}`;
            case "building":
                return `Feature Info ${this.props.info.buildingInfo?.id}`;
        }
        return "Info";
    }

    render() {
        return (<Dialog
            open={true}
            onClose={this.props.handleClose}
            maxWidth={"md"}
            fullWidth={true}
        >
            <DialogTitle>{this.getTitle()}</DialogTitle>
            <DialogContent>
                {(() => {
                    switch (this.props.info.type) {
                        case "traffic":
                            return <TrafficPopupContent info={this.props.info}/>;
                        case "building":
                            return <BuildingPopupContent info={this.props.info}/>;
                        case "pm":
                            return <PMPopupContent info={this.props.info}/>;
                    }
                })()}
            </DialogContent>
            <DialogActions>
                <Button onClick={this.props.handleClose} color="primary">
                    Close
                </Button>
            </DialogActions>
        </Dialog>);
    }
}

